==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/outputs/AzureArcKubernetesHelmApplicationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure arc kubernetes helm application configurations.
 * @property artifactProfile Azure arc kubernetes artifact profile.
 * @property artifactType The artifact type.
 * Expected value is 'HelmPackage'.
 * @property dependsOnProfile Depends on profile definition.
 * @property deployParametersMappingRuleProfile Deploy mapping rule profile.
 * @property name The name of the network function application.
 */
public data class AzureArcKubernetesHelmApplicationResponse(
    public val artifactProfile: AzureArcKubernetesArtifactProfileResponse? = null,
    public val artifactType: String,
    public val dependsOnProfile: DependsOnProfileResponse? = null,
    public val deployParametersMappingRuleProfile: AzureArcKubernetesDeployMappingRuleProfileResponse? =
        null,
    public val name: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.outputs.AzureArcKubernetesHelmApplicationResponse):
            AzureArcKubernetesHelmApplicationResponse = AzureArcKubernetesHelmApplicationResponse(
            artifactProfile = javaType.artifactProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesArtifactProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            artifactType = javaType.artifactType(),
            dependsOnProfile = javaType.dependsOnProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.DependsOnProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            deployParametersMappingRuleProfile = javaType.deployParametersMappingRuleProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesDeployMappingRuleProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/outputs/AzureArcKubernetesHelmApplicationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure arc kubernetes helm application configurations.
 * @property artifactProfile Azure arc kubernetes artifact profile.
 * @property artifactType The artifact type.
 * Expected value is 'HelmPackage'.
 * @property dependsOnProfile Depends on profile definition.
 * @property deployParametersMappingRuleProfile Deploy mapping rule profile.
 * @property name The name of the network function application.
 */
public data class AzureArcKubernetesHelmApplicationResponse(
    public val artifactProfile: AzureArcKubernetesArtifactProfileResponse? = null,
    public val artifactType: String,
    public val dependsOnProfile: DependsOnProfileResponse? = null,
    public val deployParametersMappingRuleProfile: AzureArcKubernetesDeployMappingRuleProfileResponse? =
        null,
    public val name: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.outputs.AzureArcKubernetesHelmApplicationResponse): AzureArcKubernetesHelmApplicationResponse = AzureArcKubernetesHelmApplicationResponse(
            artifactProfile = javaType.artifactProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesArtifactProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            artifactType = javaType.artifactType(),
            dependsOnProfile = javaType.dependsOnProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.DependsOnProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            deployParametersMappingRuleProfile = javaType.deployParametersMappingRuleProfile().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesDeployMappingRuleProfileResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
        )
    }
}
